# Installation

In a new virtual environment, simply install the package via
[pypi](https://pypi.org/project/cliconfig/):

```bash
pip install cliconfig
```

This package is OS independent and supported on Linux, macOS and Windows.
